# Fickle

The goal of fickle is to help you load pickled data as safely as possible. The default configuration does not allow for remote code execution attacks, but may allow for infinite loops / denial of service attacks.
